<?php

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 * 
 */


include(Config::get('settings_php'));
include_once(Config::get('include_path')."/database.inc");
include_once(Config::get('include_path')."/bootstrap.inc");
include_once(Config::get('include_path')."/common.inc");

$url_array = parse_url($db_url);
$GLOBALS['url_array'] = $url_array;
include_once(Config::get('include_path')."/database.".$url_array['scheme'].".inc");

global $active_db;
$active_db = db_connect($db_url);

class ShindigIntegratorDbFetcher {
	private $db;
	private $url_prefix;
	
	// Singleton
	private static $fetcher;

	private function __construct()
	{
		global $url_array;
		$this->url_prefix = "http://" . $_SERVER['HTTP_HOST'] . $url_array['path']."/";
	}

	private function __clone()
	{
		// private, don't allow cloning of a singleton
	}

	static function get()
	{
		// This object is a singleton
		if (! isset(ShindigIntegratorDbFetcher::$fetcher)) {
			ShindigIntegratorDbFetcher::$fetcher = new ShindigIntegratorDbFetcher();
		}
		return ShindigIntegratorDbFetcher::$fetcher;
	}

	
	public function getFriendIds($user_id)
	{
		$ret = array();
		$res = db_query("select uid, buddy from buddylist where uid = %d or buddy = %d", $user_id, $user_id) or die(db_error());
		while ($row = db_fetch_array($res)) {
			if($row['uid']==$user_id)
			{
				if(!in_array($row['buddy'],$ret))
    			    $ret[] = $row['buddy'] ;
			}
			else
			{
    			if(!in_array($row['uid'],$ret))
                    $ret[] = $row['uid'] ;
			}
		}
		return $ret;
	}    

	public function getPeople($ids, $profileDetails)
	{
		$ret = array();
		foreach($ids as $id)
		{
			$user =array();
			$res = db_query("SELECT * FROM profile_values INNER JOIN profile_fields ON profile_values.fid = profile_fields.fid WHERE uid =%d", $id) or die(db_error());		
			if ($res) {
				while ($row = db_fetch_array($res)) 
				{
					$user[$row['name']] = $row['value'];
					$user['uid'] = $row['uid'];
				}			
			}	
			$user_id = $user['uid'];
			$name = new Name($user['profile_fname'] . ' ' . $user['profile_lname']);
			$name->setGivenName($user['profile_fname']);
			$name->setFamilyName($user['profile_lname']);
			$person = new Person($user['uid'], $name);
			$person->setProfileUrl($this->url_prefix . '?q=user/' . $user['uid']);
			$res = db_query("SELECT picture FROM users where uid = %d",$id) or die(db_error());	
			$row =  db_fetch_array($res);
			$person->setThumbnailUrl(! empty($row['picture']) ? $this->url_prefix.$row['picture'] : '');
						if ($user['Gender'] == 'f') {
						    $person->setGender('FEMALE');
					    } else {
						    $person->setGender('MALE');
					    }
	
			
				$ret[$user_id] = $person;
			
		}
		
		return $ret;
	}
	
	public function setAppData($user_id, $key, $value, $app_id)
	{
		$user_id = db_escape_string($user_id);
		$key = db_escape_string($key);
		$value = db_escape_string($value);
		$app_id = db_escape_string($app_id);
		
		if (empty($value)) {
			if (! db_query("delete from application_settings where application_id = %d and user_id = %d and name = '%s'", $app_id, $user_id, $key)) {
				return false;
			}
		} else {
			if (! db_query("insert into application_settings (application_id, user_id, module_id, name, value) values (%d, %d, 0, '%s', '%s') on duplicate key update value = '%s'", $app_id, $app_id, $key, $value, $value)) {
				echo "error: ".db_error();
				return false;
			}
		}
		return true;
	}

	public function getAppData($ids, $keys, $app_id)
	{
		$data = array();
		foreach ($ids as $key => $val) {
			$ids[$key] = db_escape_string($val);
		}
		if ($keys[0] == '*') {
			$keys = '';
		} else {
			foreach ($keys as $key => $val) {
				$keys[$key] = "'" . db_escape_string($val) . "'";
			}
			$keys = "and name in (" . implode(',', $keys) . ")";
		}
		$res = db_query("select user_id, name, value from application_settings where application_id = %d and user_id in (" . implode(',', $ids) . ") $keys", $app_id);
		while (list($user_id, $key, $value) = @mysql_fetch_row($res)) {
			if (! isset($data[$user_id])) {
				$data[$user_id] = array();
			}
			$data[$user_id][$key] = $value;
		}
		return $data;
	}
	
	public function createActivity($user_id, $activity, $app_id = '0')
	{
		$app_id = db_escape_string($app_id);
		$user_id = db_escape_string($user_id);
		$title = isset($activity['title']) ? trim($activity['title']) : '';
		$body = isset($activity['body']) ? trim($activity['body']) : '';
		$title = db_escape_string($title);
		$body = db_escape_string($body);
		$time = time();
		db_query("insert into activities (id, user_id, app_id, title, body, created) values (0, %d, %d, '%s', '%s', $time)", $user_id, $app_id, $title, $body);
		if (! ($activityId = mysql_insert_id())) {
			echo "here";
			return false;
		}
		$mediaItems = isset($activity['mediaItems']) ? $activity['mediaItems'] :  array();
		if (count($mediaItems)) {
			foreach ($mediaItems as $mediaItem) {
				$type = isset($mediaItem['type']) ? $mediaItem['type'] : '';
				$mimeType = isset($mediaItem['mimeType']) ? $mediaItem['mimeType'] : '';
				$url = isset($mediaItem['url']) ? $mediaItem['url'] : '';
				$type = db_escape_string(trim($type));
				$mimeType = db_escape_string(trim($mimeType));
				$url = db_escape_string(trim($url));
				db_query("insert into activity_media_items (id, activity_id, mime_type, media_type, url) values (0, %d, '%s', '%s', '%s')", $activityId, $mimeType, $type, $url);			
			}
		}
		return true;
	}

	public function getActivities($ids)
	{
		$activities = array();
		foreach ($ids as $key => $val) {
			$ids[$key] = db_escape_string($val);
		}
		$res = db_query("
			select 
				activities.user_id as user_id,
				activities.id as activity_id,
				activities.title as activity_title,
				activities.body as activity_body,
				activities.created as created
			from 
				activities
			where
				activities.user_id in (" . implode(',', $ids) . ")
			order by 
				created desc
			");
		while ($row = db_fetch_array($res)) {
			$activity = new Activity($row['activity_id'], $row['user_id']);
			$activity->setStreamTitle('activities');
			$activity->setTitle($row['activity_title']);
			$activity->setBody($row['activity_body']);
			$activity->setPostedTime($row['created']);
			$activity->setMediaItems($this->getMediaItems($row['activity_id']));
			$activities[] = $activity;
		}
		return $activities;
	}

	private function getMediaItems($activity_id)
	{
		$media = array();
		$activity_id = db_escape_string($activity_id);
		$res = db_query("select mime_type, media_type, url from activity_media_items where activity_id = %s", $activity_id);
		while ($row = db_fetch_array($res)) {
			$media[] = new MediaItem($row['mime_type'], $row['media_type'], $row['url']);
		}
		return $media;
	}


}
?>

